==> qttranslations-opensource-src_5.6.0.orig.tar.xz: qttranslations-opensource-src-5.6.0/translations/qtwebengine_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Необхідна автентифікація</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Користувач:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Скасувати</translation>
    </message>
    <message>
        <source>&amp;Log In</source>
        <translation>&amp;Увійти</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Follow Link</source>
        <translation>Йти за посиланням</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперед</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Копіювати посилання</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Зберегти посилання</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Копіювати адресу зображення</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Копіювати зображення</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Зберегти зображення</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Копіювати адресу медіа</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Зберегти медіа</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Грати/пауза</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Петля</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Без звуку</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Елементи керування</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Дослідити елемент</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Вийти з повноекранного режиму</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперед</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стор</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вирізати</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Повернути</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторити</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Виділити все</translation>
    </message>
    <message>
        <source>Paste and Match Style</source>
        <translation>Вставити без форматування</translation>
    </message>
    <message>
        <source>Open Link in This Window</source>
        <translation>Відкрити посилання в цьому вікні</translation>
    </message>
    <message>
        <source>Open Link in New Window</source>
        <translation>Відкрити посилання в новому вікні</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Відкрити посилання в новій вкладці</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Копіювати посилання</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Зберегти посилання</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Копіювати зображення</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Копіювати адресу зображення</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Зберегти зображення</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Копіювати адресу медіа</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Елементи керування</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Петля</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Грати/пауза</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Без звуку</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Зберегти медіа</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Дослідити елемент</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Вийти з повноекранного режиму</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Закрити сторінку</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Ви впевненні, що бажаєте покинути цю сторінку?</translation>
    </message>
    <message>
        <source>Follow Link</source>
        <translation>Йти за посиланням</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперед</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>Пере&amp;завантажити</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Виберіть теку для завантаження</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Повідомлення Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Підтвердження Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Запит Javascript - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Ви впевненні, що бажаєте покинути цю сторінку?</translation>
    </message>
</context>
<context>
    <name>QtWebEngineExperimentalPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineViewExperimental</source>
        <translation>Неможливо створити окремий екземпляр WebEngineViewExperimental</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineViewport</source>
        <translation>Неможливо створити окремий екземпляр WebEngineViewport</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create separate instance of WebEngineLoadRequest</source>
        <translation>Неможливо створити окремий екземпляр WebEngineLoadRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNavigationRequest</source>
        <translation>Неможливо створити окремий екземпляр WebEngineNavigationRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineCertificateError</source>
        <translation>Неможливо створити окремий екземпляр WebEngineCertificateError</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Неможливо створити окремий екземпляр WebEngineDownloadItem</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation>Неможливо створити окремий екземпляр WebEngineNewViewRequest</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineSettings</source>
        <translation>Неможливо створити окремий екземпляр WebEngineSettings</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Неможливо створити окремий екземпляр NavigationHistory</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Неможливо створити окремий екземпляр FullScreenRequest</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Неможливо створити окремий екземпляр WebEngineErrorPage</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Підключення до проксі &quot;%1&quot; з використанням:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2</source>
        <translation>Введіть ім&apos;я користувача та пароль для &quot;%1&quot; at %2</translation>
    </message>
</context>
</TS>

==> qttranslations-opensource-src_5.6.1.orig.tar.xz: qttranslations-opensource-src-5.6.1/translations/qtwebengine_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Необхідна автентифікація</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Користувач:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Скасувати</translation>
    </message>
    <message>
        <source>&amp;Log In</source>
        <translation>&amp;Увійти</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Follow Link</source>
        <translation>Йти за посиланням</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперед</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Копіювати посилання</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Зберегти посилання</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Копіювати адресу зображення</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Копіювати зображення</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Зберегти зображення</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Копіювати адресу медіа</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Зберегти медіа</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Грати/пауза</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Петля</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Без звуку</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Елементи керування</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Дослідити елемент</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Вийти з повноекранного режиму</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперед</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стор</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вирізати</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Повернути</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторити</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Виділити все</translation>
    </message>
    <message>
        <source>Paste and Match Style</source>
        <translation>Вставити без форматування</translation>
    </message>
    <message>
        <source>Open Link in This Window</source>
        <translation>Відкрити посилання в цьому вікні</translation>
    </message>
    <message>
        <source>Open Link in New Window</source>
        <translation>Відкрити посилання в новому вікні</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Відкрити посилання в новій вкладці</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Копіювати посилання</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Зберегти посилання</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Копіювати зображення</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Копіювати адресу зображення</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Зберегти зображення</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Копіювати адресу медіа</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Елементи керування</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Петля</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Грати/пауза</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Без звуку</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Зберегти медіа</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Дослідити елемент</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Вийти з повноекранного режиму</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Закрити сторінку</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Ви впевненні, що бажаєте покинути цю сторінку?</translation>
    </message>
    <message>
        <source>Follow Link</source>
        <translation>Йти за посиланням</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперед</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>Пере&amp;завантажити</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Виберіть теку для завантаження</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Повідомлення Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Підтвердження Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Запит Javascript - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Ви впевненні, що бажаєте покинути цю сторінку?</translation>
    </message>
</context>
<context>
    <name>QtWebEngineExperimentalPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineViewExperimental</source>
        <translation>Неможливо створити окремий екземпляр WebEngineViewExperimental</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineViewport</source>
        <translation>Неможливо створити окремий екземпляр WebEngineViewport</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create separate instance of WebEngineLoadRequest</source>
        <translation>Неможливо створити окремий екземпляр WebEngineLoadRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNavigationRequest</source>
        <translation>Неможливо створити окремий екземпляр WebEngineNavigationRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineCertificateError</source>
        <translation>Неможливо створити окремий екземпляр WebEngineCertificateError</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Неможливо створити окремий екземпляр WebEngineDownloadItem</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation>Неможливо створити окремий екземпляр WebEngineNewViewRequest</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineSettings</source>
        <translation>Неможливо створити окремий екземпляр WebEngineSettings</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Неможливо створити окремий екземпляр NavigationHistory</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Неможливо створити окремий екземпляр FullScreenRequest</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Неможливо створити окремий екземпляр WebEngineErrorPage</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Підключення до проксі &quot;%1&quot; з використанням:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>Введіть ім&apos;я користувача та пароль для &quot;%1&quot; на %2://%3</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2</source>
        <translation type="vanished">Введіть ім&apos;я користувача та пароль для &quot;%1&quot; at %2</translation>
    </message>
</context>
</TS>
